#[non_exhaustive]pub struct ActivePowerControl {
pub participate: bool,
pub droop_percent: Option<f64>,
pub participation_factor: Option<f64>,
pub minimum_target_active_power_mw: Option<f64>,
pub maximum_target_active_power_mw: Option<f64>,
}Expand description
Active power control settings for a generator or storage device.
droop_percent is the governor speed changer droop: the negated change in
active power divided by the change in frequency, normalized by nominal
power and nominal frequency, and expressed as a percentage.
participation_factor is the nonnegative distributed slack participation
factor. The target limits, when present, override the equipment active power
limits for active power control operations only.
It is distinct from MATPOWER’s area participation factor (APF) in Generator::caps.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.participate: booldroop_percent: Option<f64>participation_factor: Option<f64>minimum_target_active_power_mw: Option<f64>maximum_target_active_power_mw: Option<f64>Implementations
Sourceimpl ActivePowerControl
impl ActivePowerControl
pub fn new(participate: bool) -> ActivePowerControl