#[non_exhaustive]pub struct BoundaryLine {
pub component: ComponentId,
pub voltage_level: ComponentId,
pub active_power_setpoint_mw: f64,
pub reactive_power_setpoint_mvar: f64,
pub resistance_ohm: f64,
pub reactance_ohm: f64,
pub conductance_siemens: f64,
pub susceptance_siemens: f64,
pub pairing_key: Option<String>,
pub generation: Option<BoundaryLineGeneration>,
pub calculation_load: Option<ComponentId>,
pub calculation_generator: Option<ComponentId>,
}Expand description
One PowSybl boundary line retained beside the balanced calculation view.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdvoltage_level: ComponentIdactive_power_setpoint_mw: f64reactive_power_setpoint_mvar: f64resistance_ohm: f64reactance_ohm: f64conductance_siemens: f64susceptance_siemens: f64pairing_key: Option<String>generation: Option<BoundaryLineGeneration>calculation_load: Option<ComponentId>calculation_generator: Option<ComponentId>Trait Implementations
Sourceimpl Clone for BoundaryLine
impl Clone for BoundaryLine
Sourcefn clone(&self) -> BoundaryLine
fn clone(&self) -> BoundaryLine
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundaryLine
impl Debug for BoundaryLine
Sourceimpl<'de> Deserialize<'de> for BoundaryLine
impl<'de> Deserialize<'de> for BoundaryLine
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BoundaryLine, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BoundaryLine, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BoundaryLine
impl JsonSchema for BoundaryLine
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BoundaryLine
impl PartialEq for BoundaryLine
Sourcefn eq(&self, other: &BoundaryLine) -> bool
fn eq(&self, other: &BoundaryLine) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BoundaryLine
impl Serialize for BoundaryLine
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for BoundaryLine