#[non_exhaustive]pub struct CalculatedBus {
pub voltage_level: ComponentId,
pub calculated_bus: BusId,
pub nodes: Vec<ComponentId>,
pub voltage_kv: Option<f64>,
pub angle_degrees: Option<f64>,
}Expand description
One calculated bus explicitly recorded in node breaker topology.
XIIDM calls this record CalculatedBus. Its node list distinguishes a bus
present in the source from a connected component PowerIO calculated when
the source omitted the record.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.voltage_level: ComponentIdcalculated_bus: BusIdnodes: Vec<ComponentId>voltage_kv: Option<f64>angle_degrees: Option<f64>Trait Implementations
Sourceimpl Clone for CalculatedBus
impl Clone for CalculatedBus
Sourcefn clone(&self) -> CalculatedBus
fn clone(&self) -> CalculatedBus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CalculatedBus
impl Debug for CalculatedBus
Sourceimpl<'de> Deserialize<'de> for CalculatedBus
impl<'de> Deserialize<'de> for CalculatedBus
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CalculatedBus, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CalculatedBus, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CalculatedBus
impl JsonSchema for CalculatedBus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CalculatedBus
impl PartialEq for CalculatedBus
Sourcefn eq(&self, other: &CalculatedBus) -> bool
fn eq(&self, other: &CalculatedBus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CalculatedBus
impl Serialize for CalculatedBus
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for CalculatedBus