#[non_exhaustive]pub struct ComponentMetadata {
pub component: ComponentId,
pub name: Option<String>,
pub equipment_container: Option<ComponentId>,
pub aliases: Vec<ComponentAlias>,
pub external_identifiers: Vec<ExternalIdentifier>,
pub properties: BTreeMap<String, String>,
pub fictitious: bool,
}Expand description
Source neutral metadata attached to one stable PowerIO component identity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdname: Option<String>equipment_container: Option<ComponentId>The equipment container that owns this component, when the source model identifies one.
aliases: Vec<ComponentAlias>external_identifiers: Vec<ExternalIdentifier>properties: BTreeMap<String, String>fictitious: boolTrait Implementations
Sourceimpl Clone for ComponentMetadata
impl Clone for ComponentMetadata
Sourcefn clone(&self) -> ComponentMetadata
fn clone(&self) -> ComponentMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentMetadata
impl Debug for ComponentMetadata
Sourceimpl<'de> Deserialize<'de> for ComponentMetadata
impl<'de> Deserialize<'de> for ComponentMetadata
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ComponentMetadata, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ComponentMetadata, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ComponentMetadata
Sourceimpl JsonSchema for ComponentMetadata
impl JsonSchema for ComponentMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ComponentMetadata
impl PartialEq for ComponentMetadata
Sourcefn eq(&self, other: &ComponentMetadata) -> bool
fn eq(&self, other: &ComponentMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ComponentMetadata
impl Serialize for ComponentMetadata
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ComponentMetadata