#[non_exhaustive]pub struct DcGround {
pub component: ComponentId,
pub equipment_container: Option<ComponentId>,
pub dc_terminal: DcTerminal,
pub rated_dc_voltage_kv: Option<f64>,
pub resistance_ohm: Option<f64>,
pub inductance_h: Option<f64>,
}Expand description
A connection from one DC node to ground.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdequipment_container: Option<ComponentId>dc_terminal: DcTerminalrated_dc_voltage_kv: Option<f64>resistance_ohm: Option<f64>inductance_h: Option<f64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DcGround
impl<'de> Deserialize<'de> for DcGround
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DcGround, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DcGround, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DcGround
impl JsonSchema for DcGround
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DcGround
impl Serialize for DcGround
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DcGround