#[non_exhaustive]pub struct DcNode {
pub component: ComponentId,
pub nominal_voltage_kv: Option<f64>,
pub dc_converter_unit: Option<ComponentId>,
pub dc_topological_node: Option<ComponentId>,
pub voltage_kv: Option<f64>,
}Expand description
A physical node in a DC network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdnominal_voltage_kv: Option<f64>XIIDM nominal voltage. CGMES DC nodes do not carry this quantity.
dc_converter_unit: Option<ComponentId>dc_topological_node: Option<ComponentId>voltage_kv: Option<f64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DcNode
impl<'de> Deserialize<'de> for DcNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DcNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DcNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DcNode
impl JsonSchema for DcNode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DcNode
impl Serialize for DcNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DcNode