#[non_exhaustive]pub struct DcSeriesDevice {
pub component: ComponentId,
pub equipment_container: Option<ComponentId>,
pub dc_terminal1: DcTerminal,
pub dc_terminal2: DcTerminal,
pub rated_dc_voltage_kv: Option<f64>,
pub resistance_ohm: Option<f64>,
pub inductance_h: Option<f64>,
}Expand description
A CGMES DC series device.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdequipment_container: Option<ComponentId>dc_terminal1: DcTerminaldc_terminal2: DcTerminalrated_dc_voltage_kv: Option<f64>resistance_ohm: Option<f64>inductance_h: Option<f64>Trait Implementations
Sourceimpl Clone for DcSeriesDevice
impl Clone for DcSeriesDevice
Sourcefn clone(&self) -> DcSeriesDevice
fn clone(&self) -> DcSeriesDevice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DcSeriesDevice
impl Debug for DcSeriesDevice
Sourceimpl<'de> Deserialize<'de> for DcSeriesDevice
impl<'de> Deserialize<'de> for DcSeriesDevice
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DcSeriesDevice, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DcSeriesDevice, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DcSeriesDevice
impl JsonSchema for DcSeriesDevice
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DcSeriesDevice
impl PartialEq for DcSeriesDevice
Sourcefn eq(&self, other: &DcSeriesDevice) -> bool
fn eq(&self, other: &DcSeriesDevice) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DcSeriesDevice
impl Serialize for DcSeriesDevice
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DcSeriesDevice