#[non_exhaustive]pub struct DcTopologicalNode {
pub component: ComponentId,
pub dc_converter_unit: Option<ComponentId>,
}Expand description
An energized connectivity node in a CGMES DC network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIddc_converter_unit: Option<ComponentId>Trait Implementations
Sourceimpl Clone for DcTopologicalNode
impl Clone for DcTopologicalNode
Sourcefn clone(&self) -> DcTopologicalNode
fn clone(&self) -> DcTopologicalNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DcTopologicalNode
impl Debug for DcTopologicalNode
Sourceimpl<'de> Deserialize<'de> for DcTopologicalNode
impl<'de> Deserialize<'de> for DcTopologicalNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DcTopologicalNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DcTopologicalNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DcTopologicalNode
Sourceimpl JsonSchema for DcTopologicalNode
impl JsonSchema for DcTopologicalNode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DcTopologicalNode
impl PartialEq for DcTopologicalNode
Sourcefn eq(&self, other: &DcTopologicalNode) -> bool
fn eq(&self, other: &DcTopologicalNode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DcTopologicalNode
impl Serialize for DcTopologicalNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DcTopologicalNode