#[non_exhaustive]pub struct HvdcConverter {
pub component: ComponentId,
pub kind: HvdcConverterKind,
pub loss_factor_percent: f64,
pub voltage_regulator_on: Option<bool>,
pub voltage_setpoint_kv: Option<f64>,
pub reactive_power_setpoint_mvar: Option<f64>,
pub power_factor: Option<f64>,
pub regulating_terminal: Option<TerminalReference>,
}Expand description
One AC terminal converter station of an HVDC line.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdkind: HvdcConverterKindloss_factor_percent: f64Converter losses as a percentage of active power.
voltage_regulator_on: Option<bool>voltage_setpoint_kv: Option<f64>reactive_power_setpoint_mvar: Option<f64>power_factor: Option<f64>regulating_terminal: Option<TerminalReference>Trait Implementations
Sourceimpl Clone for HvdcConverter
impl Clone for HvdcConverter
Sourcefn clone(&self) -> HvdcConverter
fn clone(&self) -> HvdcConverter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HvdcConverter
impl Debug for HvdcConverter
Sourceimpl<'de> Deserialize<'de> for HvdcConverter
impl<'de> Deserialize<'de> for HvdcConverter
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<HvdcConverter, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<HvdcConverter, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HvdcConverter
impl JsonSchema for HvdcConverter
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HvdcConverter
impl PartialEq for HvdcConverter
Sourcefn eq(&self, other: &HvdcConverter) -> bool
fn eq(&self, other: &HvdcConverter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HvdcConverter
impl Serialize for HvdcConverter
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for HvdcConverter