#[non_exhaustive]pub struct MinMaxReactiveLimits {
pub minimum_reactive_power_mvar: f64,
pub maximum_reactive_power_mvar: f64,
pub properties: BTreeMap<String, String>,
}Expand description
Reactive power limits that do not vary with active power.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.minimum_reactive_power_mvar: f64maximum_reactive_power_mvar: f64properties: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for MinMaxReactiveLimits
impl Clone for MinMaxReactiveLimits
Sourcefn clone(&self) -> MinMaxReactiveLimits
fn clone(&self) -> MinMaxReactiveLimits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MinMaxReactiveLimits
impl Debug for MinMaxReactiveLimits
Sourceimpl<'de> Deserialize<'de> for MinMaxReactiveLimits
impl<'de> Deserialize<'de> for MinMaxReactiveLimits
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MinMaxReactiveLimits, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MinMaxReactiveLimits, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MinMaxReactiveLimits
impl JsonSchema for MinMaxReactiveLimits
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MinMaxReactiveLimits
impl PartialEq for MinMaxReactiveLimits
Sourcefn eq(&self, other: &MinMaxReactiveLimits) -> bool
fn eq(&self, other: &MinMaxReactiveLimits) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MinMaxReactiveLimits
impl Serialize for MinMaxReactiveLimits
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for MinMaxReactiveLimits