#[non_exhaustive]pub struct ReactiveCapabilityCurve {
pub curve_style: CurveStyle,
pub properties: BTreeMap<String, String>,
pub points: Vec<ReactiveCapabilityCurvePoint>,
}Expand description
Reactive power limits that vary with active power.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.curve_style: CurveStyleproperties: BTreeMap<String, String>points: Vec<ReactiveCapabilityCurvePoint>Trait Implementations
Sourceimpl Clone for ReactiveCapabilityCurve
impl Clone for ReactiveCapabilityCurve
Sourcefn clone(&self) -> ReactiveCapabilityCurve
fn clone(&self) -> ReactiveCapabilityCurve
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReactiveCapabilityCurve
impl Debug for ReactiveCapabilityCurve
Sourceimpl<'de> Deserialize<'de> for ReactiveCapabilityCurve
impl<'de> Deserialize<'de> for ReactiveCapabilityCurve
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ReactiveCapabilityCurve, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ReactiveCapabilityCurve, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReactiveCapabilityCurve
impl JsonSchema for ReactiveCapabilityCurve
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReactiveCapabilityCurve
impl PartialEq for ReactiveCapabilityCurve
Sourcefn eq(&self, other: &ReactiveCapabilityCurve) -> bool
fn eq(&self, other: &ReactiveCapabilityCurve) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ReactiveCapabilityCurve
impl Serialize for ReactiveCapabilityCurve
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ReactiveCapabilityCurve