#[non_exhaustive]pub struct TapChanger {Show 17 fields
pub component: Option<ComponentId>,
pub transformer: ComponentId,
pub winding: u8,
pub kind: TapChangerKind,
pub tap_position: Option<i32>,
pub solved_tap_position: Option<i32>,
pub low_tap_position: i32,
pub neutral_tap_position: Option<i32>,
pub normal_tap_position: Option<i32>,
pub voltage_step_increment_percent: Option<f64>,
pub load_tap_changing_capabilities: bool,
pub regulating: bool,
pub regulation_mode: Option<TapChangerRegulationMode>,
pub regulation_value: Option<f64>,
pub target_deadband: Option<f64>,
pub regulation_terminal: Option<TerminalReference>,
pub steps: Vec<TapChangerStep>,
}Expand description
A ratio or phase tap changer attached to one transformer winding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: Option<ComponentId>The tap changer’s own identity when the source assigns one.
transformer: ComponentIdwinding: u8One for a two winding transformer, or one through three for a three winding transformer.
kind: TapChangerKindtap_position: Option<i32>Assigned tap position. XIIDM permits this to be absent for cases whose
minimum validation level is EQUIPMENT.
solved_tap_position: Option<i32>Solved tap position when a source records it separately from the assigned tap position.
low_tap_position: i32neutral_tap_position: Option<i32>Tap position at which the ratio or phase shift is neutral.
normal_tap_position: Option<i32>Normal tap position declared by the equipment model.
voltage_step_increment_percent: Option<f64>Voltage increment per tap position, in percent, for ratio and nonlinear phase tap changers.
load_tap_changing_capabilities: boolregulating: boolregulation_mode: Option<TapChangerRegulationMode>regulation_value: Option<f64>kV, MVAr, MW, or A according to regulation_mode.
target_deadband: Option<f64>Deadband in the same unit as regulation_value.
regulation_terminal: Option<TerminalReference>steps: Vec<TapChangerStep>Trait Implementations
Sourceimpl Clone for TapChanger
impl Clone for TapChanger
Sourcefn clone(&self) -> TapChanger
fn clone(&self) -> TapChanger
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TapChanger
impl Debug for TapChanger
Sourceimpl<'de> Deserialize<'de> for TapChanger
impl<'de> Deserialize<'de> for TapChanger
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TapChanger, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TapChanger, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TapChanger
impl JsonSchema for TapChanger
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TapChanger
impl PartialEq for TapChanger
Sourcefn eq(&self, other: &TapChanger) -> bool
fn eq(&self, other: &TapChanger) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TapChanger
impl Serialize for TapChanger
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for TapChanger