#[non_exhaustive]pub struct TerminalReference {
pub equipment: ComponentId,
pub terminal: u8,
}Expand description
A reference to one numbered terminal of an equipment record.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.equipment: ComponentIdterminal: u8Trait Implementations
Sourceimpl Clone for TerminalReference
impl Clone for TerminalReference
Sourcefn clone(&self) -> TerminalReference
fn clone(&self) -> TerminalReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TerminalReference
impl Debug for TerminalReference
Sourceimpl<'de> Deserialize<'de> for TerminalReference
impl<'de> Deserialize<'de> for TerminalReference
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TerminalReference, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TerminalReference, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TerminalReference
Sourceimpl JsonSchema for TerminalReference
impl JsonSchema for TerminalReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TerminalReference
impl PartialEq for TerminalReference
Sourcefn eq(&self, other: &TerminalReference) -> bool
fn eq(&self, other: &TerminalReference) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TerminalReference
impl Serialize for TerminalReference
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for TerminalReference