#[non_exhaustive]pub struct TieLine {
pub component: ComponentId,
pub boundary_line1: ComponentId,
pub boundary_line2: ComponentId,
pub calculation_branch: Option<ComponentId>,
}Expand description
A PowSybl tie line and the two boundary lines that define it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdboundary_line1: ComponentIdboundary_line2: ComponentIdcalculation_branch: Option<ComponentId>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for TieLine
impl<'de> Deserialize<'de> for TieLine
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TieLine, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TieLine, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TieLine
Sourceimpl JsonSchema for TieLine
impl JsonSchema for TieLine
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TieLine
impl Serialize for TieLine
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for TieLine