#[non_exhaustive]pub struct VoltageSourceConverter {Show 38 fields
pub component: ComponentId,
pub dc_converter_unit: Option<ComponentId>,
pub dc_terminal1: DcTerminal,
pub dc_terminal2: DcTerminal,
pub base_apparent_power_mva: Option<f64>,
pub minimum_active_power_mw: Option<f64>,
pub maximum_active_power_mw: Option<f64>,
pub minimum_dc_voltage_kv: Option<f64>,
pub maximum_dc_voltage_kv: Option<f64>,
pub rated_dc_voltage_kv: Option<f64>,
pub valve_u0_kv: Option<f64>,
pub number_of_valves: Option<u32>,
pub idle_loss_mw: Option<f64>,
pub switching_loss_mw_per_ampere: Option<f64>,
pub resistive_loss_ohm: Option<f64>,
pub control_mode: Option<AcDcConverterControlMode>,
pub active_power_at_pcc_mw: Option<f64>,
pub reactive_power_at_pcc_mvar: Option<f64>,
pub target_active_power_mw: Option<f64>,
pub target_dc_voltage_kv: Option<f64>,
pub pcc_terminal: Option<TerminalReference>,
pub droop_curve: Option<DroopCurve>,
pub droop: Option<f64>,
pub droop_compensation: Option<f64>,
pub q_share: Option<f64>,
pub maximum_modulation_index: Option<f64>,
pub maximum_valve_current_a: Option<f64>,
pub voltage_regulator_on: Option<bool>,
pub voltage_setpoint_kv: Option<f64>,
pub reactive_power_setpoint_mvar: Option<f64>,
pub reactive_limits: Option<ReactiveLimits>,
pub pole_loss_active_power_mw: Option<f64>,
pub dc_current_a: Option<f64>,
pub ac_voltage_kv: Option<f64>,
pub dc_voltage_kv: Option<f64>,
pub delta_degrees: Option<f64>,
pub uf_kv: Option<f64>,
pub uv_kv: Option<f64>,
}Expand description
A voltage source converter connected to an AC voltage level and two DC nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIddc_converter_unit: Option<ComponentId>dc_terminal1: DcTerminaldc_terminal2: DcTerminalbase_apparent_power_mva: Option<f64>minimum_active_power_mw: Option<f64>maximum_active_power_mw: Option<f64>minimum_dc_voltage_kv: Option<f64>maximum_dc_voltage_kv: Option<f64>rated_dc_voltage_kv: Option<f64>valve_u0_kv: Option<f64>number_of_valves: Option<u32>idle_loss_mw: Option<f64>switching_loss_mw_per_ampere: Option<f64>resistive_loss_ohm: Option<f64>control_mode: Option<AcDcConverterControlMode>active_power_at_pcc_mw: Option<f64>Active power at the point of common coupling, using load sign convention.
reactive_power_at_pcc_mvar: Option<f64>Reactive power at the point of common coupling, using load sign convention.
target_active_power_mw: Option<f64>Active power target at the point of common coupling, using load sign convention.
target_dc_voltage_kv: Option<f64>pcc_terminal: Option<TerminalReference>droop_curve: Option<DroopCurve>droop: Option<f64>CGMES scalar droop. This is not the XIIDM piecewise DroopCurve.
droop_compensation: Option<f64>maximum_modulation_index: Option<f64>maximum_valve_current_a: Option<f64>voltage_regulator_on: Option<bool>voltage_setpoint_kv: Option<f64>reactive_power_setpoint_mvar: Option<f64>reactive_limits: Option<ReactiveLimits>pole_loss_active_power_mw: Option<f64>dc_current_a: Option<f64>ac_voltage_kv: Option<f64>dc_voltage_kv: Option<f64>delta_degrees: Option<f64>uf_kv: Option<f64>uv_kv: Option<f64>Trait Implementations
Sourceimpl Clone for VoltageSourceConverter
impl Clone for VoltageSourceConverter
Sourcefn clone(&self) -> VoltageSourceConverter
fn clone(&self) -> VoltageSourceConverter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoltageSourceConverter
impl Debug for VoltageSourceConverter
Sourceimpl<'de> Deserialize<'de> for VoltageSourceConverter
impl<'de> Deserialize<'de> for VoltageSourceConverter
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VoltageSourceConverter, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VoltageSourceConverter, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VoltageSourceConverter
impl JsonSchema for VoltageSourceConverter
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VoltageSourceConverter
impl PartialEq for VoltageSourceConverter
Sourcefn eq(&self, other: &VoltageSourceConverter) -> bool
fn eq(&self, other: &VoltageSourceConverter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VoltageSourceConverter
impl Serialize for VoltageSourceConverter
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for VoltageSourceConverter